summaryrefslogtreecommitdiffstats
path: root/client
diff options
context:
space:
mode:
authorArtur Signell <artur@vaadin.com>2015-07-30 13:39:59 +0300
committerpatrik <patrik@vaadin.com>2015-08-04 10:49:35 +0300
commitd07dde9d6e5fbdf3b385f6964f2499bd440e5873 (patch)
tree37c64dd7d25fdf4d384e35383ee1f826625f49c7 /client
parent3f7bf5a86185ad8f89ea001fa5b2feab9d6e5db5 (diff)
downloadvaadin-framework-d07dde9d6e5fbdf3b385f6964f2499bd440e5873.tar.gz
vaadin-framework-d07dde9d6e5fbdf3b385f6964f2499bd440e5873.zip
Enable IE stuff also needed for Edge (#18523)
Change-Id: I5f1a58710a1dd68fed6f14e8d16acadc085354b7
Diffstat (limited to 'client')
-rw-r--r--client/src/com/vaadin/client/ResourceLoader.java8
-rw-r--r--client/src/com/vaadin/client/ui/FocusableScrollPanel.java2
-rw-r--r--client/src/com/vaadin/client/ui/VRichTextArea.java2
-rw-r--r--client/src/com/vaadin/client/ui/VTextArea.java8
-rw-r--r--client/src/com/vaadin/client/ui/VWindow.java8
5 files changed, 13 insertions, 15 deletions
diff --git a/client/src/com/vaadin/client/ui/FocusableScrollPanel.java b/client/src/com/vaadin/client/ui/FocusableScrollPanel.java
index 9dd9c17675..1ac5a08ccd 100644
--- a/client/src/com/vaadin/client/ui/FocusableScrollPanel.java
+++ b/client/src/com/vaadin/client/ui/FocusableScrollPanel.java
@@ -74,7 +74,7 @@ public class FocusableScrollPanel extends SimpleFocusablePanel implements
style.setPosition(Position.FIXED);
style.setTop(0, Unit.PX);
style.setLeft(0, Unit.PX);
- if (browserInfo.isIE()) {
+ if (browserInfo.isIE() || browserInfo.isEdge()) {
// for #15294: artificially hide little bit more the
// focusElement, otherwise IE will make the window to scroll
// into it when focused
diff --git a/client/src/com/vaadin/client/ui/VRichTextArea.java b/client/src/com/vaadin/client/ui/VRichTextArea.java
index 3f63f38067..cb4482f7cb 100644
--- a/client/src/com/vaadin/client/ui/VRichTextArea.java
+++ b/client/src/com/vaadin/client/ui/VRichTextArea.java
@@ -322,7 +322,7 @@ public class VRichTextArea extends Composite implements Field, KeyPressHandler,
if ("<br>".equals(result)) {
result = "";
}
- } else if (browser.isWebkit()) {
+ } else if (browser.isWebkit() || browser.isEdge()) {
if ("<br>".equals(result) || "<div><br></div>".equals(result)) {
result = "";
}
diff --git a/client/src/com/vaadin/client/ui/VTextArea.java b/client/src/com/vaadin/client/ui/VTextArea.java
index 50930f2fee..bb3d3a476b 100644
--- a/client/src/com/vaadin/client/ui/VTextArea.java
+++ b/client/src/com/vaadin/client/ui/VTextArea.java
@@ -224,16 +224,16 @@ public class VTextArea extends VTextField implements DragImageModifier {
protected boolean browserSupportsMaxLengthAttribute() {
BrowserInfo info = BrowserInfo.get();
- if (info.isFirefox() && info.isBrowserVersionNewerOrEqual(4, 0)) {
+ if (info.isFirefox()) {
return true;
}
- if (info.isSafari() && info.isBrowserVersionNewerOrEqual(5, 0)) {
+ if (info.isSafari()) {
return true;
}
- if (info.isIE() && info.isBrowserVersionNewerOrEqual(10, 0)) {
+ if (info.isIE10() || info.isIE11() || info.isEdge()) {
return true;
}
- if (info.isAndroid() && info.isBrowserVersionNewerOrEqual(2, 3)) {
+ if (info.isAndroid()) {
return true;
}
return false;
diff --git a/client/src/com/vaadin/client/ui/VWindow.java b/client/src/com/vaadin/client/ui/VWindow.java
index c5cab8ff6b..e5e09f9f09 100644
--- a/client/src/com/vaadin/client/ui/VWindow.java
+++ b/client/src/com/vaadin/client/ui/VWindow.java
@@ -762,11 +762,9 @@ public class VWindow extends VOverlay implements ShortcutActionHandlerOwner,
modalityCurtain.removeFromParent();
- if (BrowserInfo.get().isIE()) {
- // IE leaks memory in certain cases unless we release the reference
- // (#9197)
- modalityCurtain = null;
- }
+ // IE leaks memory in certain cases unless we release the reference
+ // (#9197)
+ modalityCurtain = null;
}
/*
diff --git a/client/src/com/vaadin/client/ResourceLoader.java b/client/src/com/vaadin/client/ResourceLoader.java
index 9e9ce5ac49..559768d09c 100644
--- a/client/src/com/vaadin/client/ResourceLoader.java
+++ b/client/src/com/vaadin/client/ResourceLoader.java
@@ -283,8 +283,7 @@ public class ResourceLoader {
* @since 7.2.4
*/
public static boolean supportsInOrderScriptExecution() {
- return BrowserInfo.get().isIE()
- && BrowserInfo.get().getBrowserMajorVersion() >= 11;
+ return BrowserInfo.get().isIE11() || BrowserInfo.get().isEdge();
}
/**
@@ -486,10 +485,11 @@ public class ResourceLoader {
addOnloadHandler(linkElement, new ResourceLoadListener() {
@Override
public void onLoad(ResourceLoadEvent event) {
// Chrome && IE fires load for errors, must check
// stylesheet data
if (BrowserInfo.get().isChrome()
- || BrowserInfo.get().isIE()) {
+ || BrowserInfo.get().isIE()
+ || BrowserInfo.get().isEdge()) {
int styleSheetLength = getStyleSheetLength(url);
// Error if there's an empty stylesheet
if (styleSheetLength == 0) {
@@ -486,10 +485,11 @@ public class ResourceLoader {
public void onLoad(ResourceLoadEvent event) {
- // Chrome && IE fires load for errors, must check
+ // Chrome, IE, Edge all fire load for errors, must check
// stylesheet data
if (BrowserInfo.get().isChrome()